"""
Streamlit Application
Nicolas Atrax
"""

import streamlit as st
import pandas as pd
import chardet
import csv
import re
from datetime import date
import codecs
import src.basic as tmp


tmp.base("CleanCSVtoTSV")


# Code Start

def checkEncoding(file):
    content = file.read()
    encoding = chardet.detect(content)["encoding"].lower()
    if encoding != "ascii" and encoding != "utf-8" and encoding != "utf-8-sig":
        return False
    return True


def getSeparator(file):

    line = file.readline().decode('utf-8')

    if ',' in line:
        return ',', True

    if ';' in line:
        return ';', True

    return '\t', False


def lowerName(name):
    tmp = name
    if re.search('[a-zA-Z0-9]', name[0]) == None:
        tmp = name[1:]
    if len(tmp) < 9:
        return tmp.lower()
    tmp = name.split(' ')
    split = False
    first = ""
    second = ""
    if len(tmp) == 1 and "_" in tmp[0]:
        tmp = tmp[0].split('_')
        split = True
    if len(tmp) != 2:
        return name.lower()
    else:
        first = tmp[0][0].lower() + tmp[0][1:]
        second = tmp[1][0].lower() + tmp[1][1:]
        return first + "_" + second


def checkNameValidity(name, columnNames, registeredNames, errorMessage):
    if name in registeredNames:
        errorMessage += "Error at line 1 ! Same name for 2 differents columns! \n"
        return False, errorMessage
    return True, errorMessage


def checkColumnExistence(registeredNames, errorMessage):
    columnNames = ["authors", "title", "publication_year",
                   "publication_month", "publication_day", "abstract", "source"]
    if len(registeredNames) != 7:
        tmpMessage = "Error at line 1 ! Following columns are missing :"
        for name in columnNames:
            if name not in registeredNames:
                tmpMessage += " " + name
        errorMessage += tmpMessage + "\n"
        return False, errorMessage
    return True, errorMessage


def checkColumnNames(name, errorMessage, registeredNames, otherColumns, success):
    columnNames = ["authors", "title", "source", "publication_year",
                   "publication_month", "publication_day", "abstract"]
    name = name.replace("\n", "")
    tmpSuccess, errorMessage = checkNameValidity(name, columnNames, registeredNames, errorMessage)
    if tmpSuccess:
        if lowerName(name) in columnNames:
            registeredNames.append(name)
        else :
            otherColumns.append(name)
    if success :
        success = tmpSuccess
    return errorMessage, registeredNames, otherColumns, success


def addColumnsNamestoTSV(data, registeredNames, otherColumns):
    for name in registeredNames :
        if data != "":
            data += "\t"
        data += name
    for name in otherColumns :
        data += "\t"
        data += name
    return data

def getColumnsNames(file, separator, errorMessage):
    data = ""
    columnNb = 0
    registeredNames = []
    success = True
    reader = csv.DictReader(codecs.iterdecode(
        file, 'utf-8'), delimiter=separator)
    othersColumns = []
    for row in reader:
        for name, value in row.items():
            columnName = name.replace("\ufeff", "")
            errorMessage, registeredNames, otherColumns, success = checkColumnNames(
                name, errorMessage, registeredNames, othersColumns, success)
        success, errorMessage = checkColumnExistence(
            registeredNames, errorMessage)
        if success :
            data = addColumnsNamestoTSV(data, registeredNames, otherColumns)
        break
    data += "\n"
    return data, success, errorMessage


def checkDate(name, value, success, fill, csvLine, errorMessage):
    if name in ["publication_year", "publication_month", "publication_day"]:
        if value == "" or value == "\n":
            if fill:
                if name == "publication_year":
                    return success, str(date.today().year), errorMessage
                return success, "1", errorMessage
            errorMessage += name + " is missing at line " + \
                str(csvLine) + ". Please add it or replace blank space by \"1\".\n"
        if not value.replace("\n", "").isnumeric():
            errorMessage += "Error at line " + \
                str(csvLine) + ", wrong date ! Date is : \"" + \
                value.replace("\n", "") + "\". " + name + " must be numeric.\n"
            return False, "", errorMessage
        if int(value) <= 0:
            errorMessage += "Error at line " + str(csvLine) + ", wrong date ! Date is : \"" + value.replace(
                "\n", "") + "\". " + name + " can't be 0 or less.\n"
            return False, "", errorMessage
    return success, "", errorMessage


def checkMissing(name, value, success, fill, csvLine, errorMessage):
    if value == "" or value == "\n":
        if name not in ["publication_year", "publication_month", "publication_day"]:
            if fill:
                return success, "null", errorMessage
            errorMessage += "Error at line " + \
                str(csvLine) + " ! " + name + \
                " is missing. Please add it or replace the blank space with \"null\".\n"
            return False, "", errorMessage
        else:
            return checkDate(name, value, success, fill, csvLine, errorMessage)
    return success, "", errorMessage


def correctedSequence(text):
    if text == None:
        return ""
    tmp = text.replace("\"", "\"\"")
    find = "\t" in text or "\"" in text or "\n" in text or "," in text or ";" in text
    if find:
        if text[-1] == "\n":
            tmp = tmp[:-1]
        tmp = "\"" + tmp + "\""
    return tmp

def getContent(file, separator, data, success, fill, errorMessage):
    columnNames = ["authors", "title", "source", "publication_year",
                   "publication_month", "publication_day", "abstract"] 
    csvLine = 2
    reader = csv.DictReader(codecs.iterdecode(file, 'utf-8'), delimiter=separator)
    for row in reader:
        first = True
        tsv1 = ""
        tsv2 = ""
        for name, value in row.items():
            tmpFill = ""
            if lowerName(name) in columnNames:
                if not first :
                    tsv1 += "\t"
                success, tmpFill, errorMessage = checkMissing(
                    lowerName(name), value, success, fill, csvLine, errorMessage)
                if tmpFill != "":
                    tsv1 += tmpFill
                else:
                    success, tmpFill, errorMessage = checkDate(
                        lowerName(name), value, success, fill, csvLine, errorMessage)
                    tsv1 += correctedSequence(value)
            else :
                success, tmpFill, errorMessage = checkMissing(
                    lowerName(name), value, success, fill, csvLine, errorMessage)
                if tmpFill != "":
                    tsv2 +="\t" + tmpFill
                else:
                    tsv2 += "\t" + correctedSequence(value)
            if first:
                first = False
        csvLine += 1
        data += tsv1 + tsv2 + "\n"
    return data[:-1], success, errorMessage

# Code End

st.write(st.session_state.general_text_dict['text'])
st.session_state.fill = st.checkbox(value = True, label = st.session_state.general_text_dict['fill'])
file = st.file_uploader(
    st.session_state.general_text_dict['file'], type=["tsv", "csv"], key='file')

if file:
    name = file.name.split('.')[0] + '.tsv'
    if checkEncoding(file):
        file.seek(0)
        separator, wrongSeparators = getSeparator(file)
        file.seek(0)
        st.session_state.data, st.session_state.success, st.session_state.error = getColumnsNames(
            file, separator, "")
        file.seek(0)

        if st.session_state.success:
            st.session_state.data, st.session_state.success, st.session_state.error = getContent(
                file, separator, st.session_state.data, st.session_state.success, st.session_state.fill, st.session_state.error)
            file.seek(0)

        if st.session_state.success:
            st.write(st.session_state.general_text_dict['new_file'])
            st.download_button(name, st.session_state.data, name)
        else:
            st.write(st.session_state.general_text_dict['errorMessage'])
            st.download_button("ErrorMessage.txt",
                               st.session_state.error, "ErrorMessage.txt")
    else:
        st.write(st.session_state.general_text_dict['encoding'])

    file.close()
