"""
Streamlit Application
Loïc Chapron
"""
import requests as req
import json
import streamlit as st
from datetime import datetime
import src.basic as tmp

tmp.base("HALToGarganText")

limit = 500
limitItems = 10000


def loadApiHALNbFile(search, lang):
    url = 'http://api.archives-ouvertes.fr/search/?q=' + search + '&rows=5&fl=title_s,' + lang + \
        '_title_s,source_s,publicationDate_s,authFullName_s,' + \
        lang + '_abstract_s,abstract_s&fq=language_s:' + lang
    resp = req.get(url)
    print(url)
    try:
        docs = json.loads(resp.content)
    except Exception as e:
        docs = 0

    return docs['response']['numFound']


def loadApiHAL(search, lang, page, nbvalue):
    url = 'http://api.archives-ouvertes.fr/search/?q=' + search + '&start=' + str(page * limit) + '&rows=' + str(
        nbvalue) + '&fl=title_s,' + lang + '_title_s,source_s,publicationDate_s,authFullName_s,' + lang + '_abstract_s,abstract_s&fq=language_s:' + lang
    resp = req.get(url)
    print(url)
    try:
        docs = json.loads(resp.content)
    except Exception as e:
        docs = 0

    return docs


def getParamFromDoc(docs):
    output = ''
    for doc in docs:
        if 'en_title_s' in doc.keys():
            title = doc['en_title_s'][0]
        elif 'fr_title_s' in doc.keys():
            title = doc['fr_title_s'][0]
        elif 'title_s' in doc.keys():
            title = doc['title_s'][0]
        else:
            continue

            # Authors

        if 'authFullName_s' in doc.keys():
            authors = []
            for author in doc['authFullName_s']:
                authors.append(author)
            authors = ';'.join(authors)
        else:
            authors = ''

        # Source

        if 'source_s' in doc.keys():
            source = doc['source_s']
        else:
            source = ''

        # Abstract
        if 'en_abstract_s' in doc.keys():
            abstract = doc['en_abstract_s'][0]
        elif 'fr_abstract_s' in doc.keys():
            abstract = doc['fr_abstract_s'][0]
        elif 'abstract_s' in doc.keys():
            abstract = doc['abstract_s'][0]
        else:
            abstract = ''

        # Date

        if 'publicationDate_s' in doc.keys():
            split = doc['publicationDate_s'].split('-')
            if len(split) == 3:
                pdate = datetime.strptime(
                    doc['publicationDate_s'], '%Y-%m-%d').strftime('%Y\t%m\t%d')
            elif len(split) == 2:
                pdate = datetime.strptime(
                    doc['publicationDate_s'], '%Y-%m').strftime('%Y\t%m\t1')
            else:
                pdate = doc['publicationDate_s'] + '\t1\t1'
        else:
            pdate = '1900\t1\t1'

        abstract = abstract.encode(encoding='UTF-8', errors='ignore').decode(
            "utf-8").replace('\t', '').replace('"', '').replace('\n', '')
        title = title.encode(encoding='UTF-8', errors='ignore').decode(
            "utf-8").replace('\t', '').replace('"', '').replace('\n', '')
        source = source.encode(encoding='UTF-8', errors='ignore').decode(
            "utf-8").replace('\t', '').replace('"', '').replace('\n', '').replace('\n', '')

        # Output
        output += str(title) + "\t" + source + "\t" + str(pdate) + \
            "\t" + abstract + "\t" + authors + "\t" + str(1) + "\n"
    return output


def create_output(search, lang, nb_value):
    output = "title\tsource\tpublication_year\tpublication_month\tpublication_day\tabstract\tauthors\tweight\n"
    for i in range(0, nb_value//limit):
        response = loadApiHAL(search, lang, i, limit)
        output += getParamFromDoc(response['response']['docs'])
    if (nb_value % limit != 0):
        response = loadApiHAL(search, lang, nb_value//limit, nb_value % limit)
        output += getParamFromDoc(response['response']['docs'])
    return output


lang = {
    'Français': 'fr',
    'Anglais': 'en',
}

if 'stage_isidore' not in st.session_state:
    st.session_state.stage_isidore = 0
    st.session_state.nb_wanted = 1


def set_stage(stage):
    st.session_state.stage_isidore = stage
    st.session_state.output = ''


# txt
st.write(st.session_state.general_text_dict['text'])


# Form
form = st.form('api')

search = form.text_input(st.session_state.general_text_dict['keyword'])
language = form.selectbox(
    st.session_state.general_text_dict['lang'], lang.keys())

form.form_submit_button(
    st.session_state.general_text_dict['submit'], on_click=set_stage, args=(1,))

# API and Slider
if st.session_state.stage_isidore > 0:

    # Only call first time and after
    if 'search' not in st.session_state or 'language' not in st.session_state or search != st.session_state.search or language != st.session_state.language:
        with st.spinner(st.session_state.general_text_dict['load_api']):
            nb_doc = int(loadApiHALNbFile(search, lang[language]))
        st.session_state.nb_doc = nb_doc
        if nb_doc != 0:
            st.session_state.search = search
            st.session_state.language = language

    if st.session_state.nb_doc != 0:

        # Form with slider
        form2 = st.form('my_form2')
        form2.write(
            st.session_state.general_text_dict['nb_doc'] + str(st.session_state.nb_doc))

        if st.session_state.nb_doc > limitItems:
            form2.write(st.session_state.general_text_dict['perform1'] + str(
                limitItems) + st.session_state.general_text_dict['perform2'])
            st.session_state.nb_wanted = form2.slider(
                st.session_state.general_text_dict['nb_taken'], 1, limitItems)
        else:
            st.session_state.nb_wanted = form2.slider(
                st.session_state.general_text_dict['nb_taken'], 1, int(st.session_state.nb_doc))
        form2.form_submit_button(
            st.session_state.general_text_dict['submit'], on_click=set_stage, args=(2,))

    else:
        st.write(st.session_state.general_text_dict['overload_api'])


# Download
if st.session_state.stage_isidore > 1:

    with st.spinner(st.session_state.general_text_dict['createTSV']):
        if st.session_state.output == '':
            print(st.session_state.nb_wanted)
            st.session_state.output = create_output(
                st.session_state.search, lang[st.session_state.language], st.session_state.nb_wanted)

    st.download_button('Download TSV', st.session_state.output, 'output.csv')
