"""
Streamlit Application
Loïc Chapron
"""

import streamlit as st
import requests as req
import json
import time
from json import JSONDecodeError
import src.basic as tmp



tmp.base("IsidoreToGarganText")

numberReplies = 500  # Dont' exceed 1 000
limitItems = 5000  # Can't be superior of 10 times numberReplies
retryTime = 2


def loadApiIsidoreNumberFile(search, language):
    while (True):
        url = 'https://api.isidore.science/resource/search?q=' + search + \
            '&output=json&replies=10&language=http://lexvo.org/id/iso639-3/' + language
        st.session_state.resp = req.get(url)
        print(url)
        if st.session_state.resp.ok:
            try:
                jsontxt = json.loads(st.session_state.resp.content)
                docs = jsontxt["response"]["replies"]["meta"]["@items"]
                break
            except JSONDecodeError:
                continue
        else:
            docs = 0
            break

    return docs


def loadApiIsidorePage(search, language, page):
    url = 'https://api.isidore.science/resource/search?q=' + search + '&output=json&replies=' + \
        str(numberReplies) + '&page=' + str(page) + \
        '&language=http://lexvo.org/id/iso639-3/' + language
    resp = req.get(url)
    print(url)
    try:
        jsontxt = json.loads(resp.content)
        docs = jsontxt["response"]["replies"]["content"]["reply"]
    except Exception as e:
        docs = 0

    return docs


def create_output(search, language, nb_doc):
    output = "title\tsource\tpublication_year\tpublication_month\tpublication_day\tabstract\tauthors\tweight\n"
    nb = 0
    for i in range(1, nb_doc//numberReplies + 1):
        while (True):
            txt = loadApiIsidorePage(search, language, i)
            if txt != 0:
                break
            time.sleep(retryTime)
            print('Retry')
        tmp, nb_tmp = createFile(txt, nb_doc % numberReplies, language)
        output += tmp
        nb += nb_tmp
    if nb_doc % numberReplies != 0:
        txt = loadApiIsidorePage(search, language, nb_doc//numberReplies + 1)
        tmp, nb_tmp = createFile(txt, nb_doc % numberReplies, language)
        output += tmp
        nb += nb_tmp
    return output, nb


def createFile(docs, limit, language):

    # Output text
    output = ''
    i = 0
    nb = 0
    for doc in docs:
        if (i == limit):
            break
        i += 1
        # Title
        title = doc["isidore"]["title"]
        if (type(title) != str):
            if (type(title) == list):
                tmp = ''
                for lang in title:
                    if type(lang) != str and lang['@xml:lang'] == language[:2]:
                        tmp = lang['$']
                if tmp == '':
                    if type(title[0]) == str:
                        title = title[0]
                    else:
                        title = title[0]['$']
                else:
                    title = tmp

            else:
                title = title['$']

        # Source
        source = doc["isidore"]["source_info"]["sourceName"]["$"]

        # Author
        if doc['isidore']['enrichedCreators'] != []:
            list_author = doc["isidore"]["enrichedCreators"]["creator"]
            authors = []
            if (type(list_author) == list):
                for author in list_author:
                    authors.append(author["@origin"].replace('"', ''))
                authors = ';'.join(authors)
            else:
                authors = list_author["@origin"].replace('"', '')
        else:
            authors = ''

        # Abstract
        if 'abstract' in doc['isidore'].keys() and doc["isidore"]["abstract"] != []:
            abstract = doc["isidore"]["abstract"]
        else:
            abstract = ''
        if (type(abstract) != str):
            if type(abstract) == list:
                tmp = ''
                for lang in abstract:
                    if type(lang) != str and type(lang) != list and lang['@xml:lang'] == language[:2]:
                        tmp = lang['$']
                if tmp == '':
                    if type(abstract[0]) == str:
                        abstract = abstract[0]
                    else:
                        abstract = abstract[0]['$']
                else:
                    abstract = tmp
            else:
                abstract = abstract['$']

        if 'types' in doc['isidore'].keys():
            if type(doc['isidore']['types']['type'] == str) and doc['isidore']['types']['type'] in ['Books', 'text']:
                nb += 1
            elif type(doc['isidore']['types']['type'] == dict) and doc['isidore']['types']['type'][1] in ['Books', 'text']:
                nb += 1
        else:
            print(title)

        # Publication Date
        pdate = getGoodTime(doc["isidore"]["date"]["@origin"])

        abstract = abstract.encode(
            encoding='UTF-8', errors='ignore').decode("utf-8").replace('\t', '').replace('"', '')
        title = title.encode(
            encoding='UTF-8', errors='ignore').decode("utf-8").replace('\t', '').replace('"', '')
        source = source.encode(encoding='UTF-8', errors='ignore').decode(
            "utf-8").replace('\t', '').replace('"', '').replace('\n', '')

        # Output
        row = str(title) + "\t" + source + "\t" + str(pdate) + \
            "\t" + abstract + "\t" + authors + "\t" + str(1) + "\n"
        output += row

    return output, nb


# Need modification when Isidore upgrade his api
def getGoodTime(time):
    time = time.replace('?', '0').replace('.', '0')
    tiret = time.replace('[', '').replace(']', '').split('-')
    slash = time.replace('[', '').replace(']', '').split('/')
    if (len(tiret) == 1 and len(tiret[0]) == 4):
        if time != '0001':
            return tiret[0] + '\t1\t1'
    elif (len(tiret) > 1):
        if (len(tiret) == 2 and len(tiret[0]) == 4 and len(tiret[1]) <= 2):
            return tiret[0] + '\t' + tiret[1] + '\t1'
        elif (len(tiret) == 3 and len(tiret[0]) == 4 and len(tiret[1]) <= 2 and len(tiret[2].split('T')[0]) <= 2):
            return tiret[0] + '\t' + tiret[1] + '\t' + tiret[2].split('T')[0]
    elif (len(slash) == 1 and len(time) == 4):
        return slash[0] + '\t1\t1'
    elif (len(slash) > 1):
        if (len(slash) == 2 and len(slash[1]) == 4 and len(slash[0]) <= 2):
            return slash[1] + '\t' + slash[0] + '\t1'
        elif (len(slash) == 3 and len(slash[2]) == 4 and len(slash[1]) <= 2 and len(slash[0]) <= 2):
            return slash[2] + '\t' + slash[1] + '\t' + slash[0].split('T')[0]
    elif len(time) == 8:
        return time[:4] + '\t' + time[4:6] + '\t' + time[6:8]
    return '1900\t1\t1'


# Streamlit


lang = {
    'Français': 'fra',
    'Anglais': 'eng',
    'Espagnol': 'spa',
    'Italien': 'ita',
    'Allemand': 'deu',
}

# Can be added but low result
# 'Polonais' : 'nld',
# 'Portugais' : 'por',
# 'Russe' : 'rus'

if 'stage_isidore' not in st.session_state:
    st.session_state.stage_isidore = 0
    st.session_state.nb_wanted = 1


def set_stage(stage):
    st.session_state.stage_isidore = stage
    st.session_state.output = ''


# Image
col1, col2 = st.columns(2)
with col1:
    st.image('img/isidore_logo.png')
with col2:
    st.image('img/gargantext_logo.jpg')

# Form
form = st.form('api')

form.write(st.session_state.general_text_dict['text'])
search = form.text_input(st.session_state.general_text_dict['keyword'])
language = form.selectbox(
    st.session_state.general_text_dict['lang'], lang.keys())

form.form_submit_button(
    st.session_state.general_text_dict['submit'], on_click=set_stage, args=(1,))

# API and Slider
if st.session_state.stage_isidore > 0:

    # Only call first time and after
    if 'search' not in st.session_state or 'language' not in st.session_state or search != st.session_state.search or language != st.session_state.language:
        with st.spinner(st.session_state.general_text_dict['load_api']):
            nb_doc = int(loadApiIsidoreNumberFile(search, lang[language]))
        st.session_state.nb_doc = nb_doc
        if nb_doc != 0:
            st.session_state.search = search
            st.session_state.language = language

    if st.session_state.nb_doc != 0:

        # Form with slider
        form2 = st.form('my_form2')
        form2.write(
            st.session_state.general_text_dict['nb_doc'] + str(st.session_state.nb_doc))

        if st.session_state.nb_doc > limitItems:
            form2.write(st.session_state.general_text_dict['perform1'] + str(
                limitItems) + st.session_state.general_text_dict['perform2'])
            st.session_state.nb_wanted = form2.slider(
                st.session_state.general_text_dict['nb_taken'], 1, limitItems)
        else:
            st.session_state.nb_wanted = form2.slider(
                st.session_state.general_text_dict['nb_taken'], 1, int(st.session_state.nb_doc))
        form2.form_submit_button(
            st.session_state.general_text_dict['submit'], on_click=set_stage, args=(2,))

    else:
        st.write(st.session_state.general_text_dict['overload_api'])


# Download
if st.session_state.stage_isidore > 1:

    with st.spinner(st.session_state.general_text_dict['createTSV']):
        if st.session_state.output == '':
            st.session_state.output, st.session_state.nb_bad_file = create_output(
                st.session_state.search, lang[st.session_state.language], st.session_state.nb_wanted)

    st.write(st.session_state.general_text_dict['doc_abstract1'] + str(
        st.session_state.nb_bad_file) + st.session_state.general_text_dict['doc_abstract2'])
    st.download_button('Download TSV', st.session_state.output, 'output.csv')
