"""
Streamlit Application
Loïc Chapron
"""

import json
import pandas as pd
import datetime
import zipfile
import streamlit as st
import src.basic as tmp


tmp.base("IstexToGarganText")


def read_zip(zip_file):
    output = []
    dup = 0
    with zipfile.ZipFile(zip_file, 'r') as zip_ref:
        for file in zip_ref.namelist():

            if file.split('.')[1] != 'json' or file.split('.')[0] == 'manifest':
                continue
            try:

                with zip_ref.open(file) as f:
                    data = json.load(f)
                    article = pd.json_normalize(data)
                    f.close()

                temp = {}
                temp["title"] = article.get("title", '')[0].encode(
                    encoding='UTF-8', errors='ignore').decode("utf-8").replace("\t", " ")

                try:
                    temp["abstract"] = article.get("abstract", "")[0].encode(
                        encoding='UTF-8', errors='ignore').decode("utf-8").replace("\t", " ")
                except Exception as e:
                    temp["abstract"] = ''

                try:
                    authors = ""
                    for author in article["author"][0]:
                        authors += author["name"]+"; "
                    authors = authors[:-2]
                except:
                    author = ''

                temp["code"] = article.get("_id")[0]
                temp["authors"] = authors.encode(
                    encoding='UTF-8', errors='ignore').decode("utf-8").replace("\t", " ")
                try:
                    temp["source"] = article.get('host.title')[0].encode(
                        encoding='UTF-8', errors='ignore').decode("utf-8").replace("\t", " ")
                except:
                    temp["source"] = ''

                try:
                    temp["publication_year"] = article["publicationDate"][0]
                except:
                    temp["publication_year"] = datetime.date.today().year
                temp["publication_year"] = article.get(
                    "publicationDate", datetime.date.today().year)[0]
                temp["publication_month"] = 1
                temp["publication_day"] = 1

                output.append(temp)

            except Exception as e:
                dup += 1

        zip_ref.close()

    output = pd.DataFrame(output)
    duplicated = output['title'].str.lower().replace(
        ",", "", regex=True).duplicated()

    if (duplicated.any()):
        dup += duplicated.sum()
    output = output.drop(['code'], axis=1)
    output = output[~duplicated]
    df = pd.DataFrame(output)
    return df.to_csv(index=False, sep='\t'), dup


st.write(st.session_state.general_text_dict['text'])

file = st.file_uploader(
    st.session_state.general_text_dict['file'], type=["zip"], key='file')

if file:
    try:
        name = file.name.split('.')[0] + '.csv'
        res, nb_dup = read_zip(file)
        if nb_dup:
            st.write(st.session_state.general_text_dict['dup1'] + str(
                nb_dup) + st.session_state.general_text_dict['dup2'])
        st.write(st.session_state.general_text_dict['new_file'])
        st.download_button(name, res, name)
    except Exception as e:
        st.write(st.session_state.general_text_dict['error'])
        print(e)
    file.close()
