"""
Streamlit Application
Loïc Chapron
"""

import streamlit as st
from datetime import datetime
import pandas as pd
import src.basic as tmp


tmp.base("MergeTermGarganText")


def fuzeFile(file1, file2):

    ngrams1 = file1['NgramsTerms']['data']
    ngrams2 = file2['NgramsTerms']['data']
    merged = {}

    roots = []
    leafs = []

    # find the roots of list 1
    for root in ngrams1.keys():

        if ngrams1[root]['list'] == "MapTerm":

            roots.append(root)
            leafs = leafs + ngrams1[root]['children']

    # merge list 2 in list 1
    for root in ngrams2.keys():

        if root in roots:

            ngrams1[root]['children'] = list(
                set(ngrams1[root]['children'] + ngrams2[root]['children']))

        else:

            if root not in leafs:

                ngrams1[root] = ngrams2[root]
                children = ngrams1[root]['children']
                ngrams1[root]['children'] = []
                for child in children:
                    if child not in root or child not in leafs:
                        ngrams1[root]['children'].append(child)

    # clean the merged list
    for root in ngrams1.keys():

        if ngrams1[root]['list'] == "MapTerm":

            if len(ngrams1[root]['children']) == 0:

                ngrams1[root]['children'] = []

            merged[root] = ngrams1[root]

    file1['NgramsTerms']['data'] = merged
    file1['Authors']['data'] = {}
    file1['Institutes']['data'] = {}
    file1['Sources']['data'] = {}

    return file1.to_json(orient='columns', indent=4)


st.write(st.session_state.general_text_dict['text'])
col1, col2 = st.columns(2)
with col1:
    file1 = st.file_uploader(st.session_state.general_text_dict['file'], type=[
                             "json"], key='file1')
with col2:
    file2 = st.file_uploader(st.session_state.general_text_dict['file'], type=[
                             "json"], key='file2')


if (file1 and file2):
    try:
        df1 = pd.read_json(file1)
        df2 = pd.read_json(file2)
        time = datetime.strftime(datetime.now(), "%d-%m-%Y/%H:%M:%S")
        name = 'output-' + time + '.json'
        st.download_button(
            st.session_state.general_text_dict['new_file'], fuzeFile(df1, df2), name)
    except Exception as e:
        st.write("Error : one of the file isn't valid")

    file1.close()
    file2.close()
