"""
Streamlit Application
Loïc Chapron
"""

import streamlit as st
import lib.nbib.nbib as nbib
import re
import calendar
import src.basic as tmp


tmp.base("PubMedToGarganText")


def read_file(file):
    docs = nbib.read(file.read().decode('utf-8'))
    output = "title\tsource\tpublication_year\tpublication_month\tpublication_day\tabstract\tauthors\tweight\n"

    for doc in docs:

        keys = doc.keys()

        if len(list(set(['title', 'publication_date', 'authors']) & set(keys))) < 3:
            continue

        if 'journal' in keys:
            source = doc['journal']
        else:
            source = ""

        if 'abstract' in keys:
            abstract = doc['abstract']
        else:
            abstract = ""

        title = doc['title']
        date = doc['publication_date'].split(' ')
        year = date[0]
        if len(date) > 1:
            try:
                month = list(calendar.month_abbr).index(date[1])
            except Exception as e:
                month = '1'
        else:
            month = '1'

        if len(date) > 2:
            day = date[2]
        else:
            day = '1'

        abstract = re.sub('\"', "", abstract).replace("\t", "")
        title = re.sub('\"', "", title).replace("\t", "")

        authors_lst = []

        for author in doc['authors']:

            authors_lst.append((author['author']).replace(',', ''))

        authors = ','.join(authors_lst)

        row = str(title) + "\t" + "scopus" + "\t" + year + "\t" + str(month) + \
            "\t" + str(day) + "\t" + abstract + "\t" + \
            authors + "\t" + str(1) + "\n"

        output += row
    return output


st.write(st.session_state.general_text_dict['text'])
file = st.file_uploader(
    st.session_state.general_text_dict['file'], type=["txt"], key='file')

if file:
    try:
        name = file.name.split('.')[0] + '.csv'
        st.write(st.session_state.general_text_dict['new_file'])

        st.download_button(name, read_file(file), name)
    except Exception as e:
        st.write(st.session_state.general_text_dict['error'])
        print(e)
    file.close()
