"""
Streamlit Application
Nicolas Atrax
"""

import streamlit as st
import pandas as pd
import chardet
import re
import codecs
import os
import tempfile
import csv
from lib.langdetect.langdetect import detect
from lib.langdetect.langdetect.lang_detect_exception import LangDetectException
from lib.googletrans.googletrans import Translator as GoogleTranslator
from lib.googletrans.googletrans import LANGUAGES
import src.basic as tmp

tmp.base("TsvTranslator")

# Tool Code Start


def detectLanguages(abstract, languages):
    if re.search('[a-zA-Z]', abstract) == None:
        return languages
    try:
        tmp = detect(abstract)
        if tmp in languages:
            languages[tmp] += 1
        else:
            languages[tmp] = 1
    except LangDetectException:
        pass
    return languages


def estimateLanguagesPercentage(languages):
    st.session_state.detected = ""
    total = 0
    res = {}
    for l in languages:
        total += languages[l]
    for l in languages:
        tmp = round((languages[l] / total) * 100, 1)
        if tmp >= 15:
            res[l] = tmp
            if st.session_state.detected != "":
                st.session_state.detected += "| "
            st.session_state.detected += l + " : " + str(tmp) + "%"
    print(res)
    return res


def inspectLanguages(file):
    languages = {}
    reader = csv.DictReader(codecs.iterdecode(
        file, 'utf-8'), delimiter=st.session_state.separator)
    for row in reader:
        for name, value in row.items():
            if name.lower() == 'abstract':
                languages = detectLanguages(value, languages)
    file.seek(0)
    return estimateLanguagesPercentage(languages)


def translate(text, srcLang, destLang):
    translator = GoogleTranslator()
    return translator.translate(text, src=srcLang, dest=destLang).text


def correctedSequence(text, separator):
    tmp = text.replace("\"", "\"\"")
    find = separator in text or "\"" in text or "\n" in text
    if find:
        if text[len(text) - 1] == "\n":
            tmp = tmp[:-1]
        tmp = "\"" + tmp + "\""
    return tmp


def getSeparator(file):

    line = file.readline().decode('utf-8')
    file.seek(0)
    if ',' in line:
        return ','
    if ';' in line:
        return ';'
    return '\t'


def getColumnsNames(file):
    data = ""
    total = 1

    reader = csv.DictReader(codecs.iterdecode(
        file, 'utf-8'), delimiter=st.session_state.separator)
    columnsNames = []
    for row in reader:
        for name, value in row.items():
            if data != "":
                data += "\t"
            data += name.replace("\ufeff", "")
        break
    data += "\n"
    total += sum(1 for row in reader)
    file.seek(0)
    return data, total


def getContent(file, data, total, separator):
    percent = -1
    reader = csv.DictReader(codecs.iterdecode(
        file, 'utf-8'), delimiter=separator)
    count = 1
    bar = st.progress(0,
                      st.session_state.general_text_dict['loading'] + "0%")
    for row in reader:
        tmp = ""
        first = True
        loading = int(count / total * 100)
        bar.progress(loading,
                     st.session_state.general_text_dict['loading'] + str(loading) + "%")
        for name, value in row.items():
            if not first:
                tmp += "\t"
            else:
                first = False
            if name.lower() == "abstract" and re.search('[a-zA-Z]', value) != None:
                tmp += correctedSequence(translate(value,
                                                   st.session_state.srcLang, st.session_state.destLang), separator)
            else:
                tmp += correctedSequence(value, separator)
        count += 1
        data += tmp + "\n"
    return data


def translateTSV(file):

    if st.session_state.srcLang == st.session_state.destLang:
        return None
    data, total = getColumnsNames(file)
    data = getContent(file, data, total, st.session_state.separator)
    return data


# Tool Code End


form = st.form('api')

# Page Code Start

if 'page' not in st.session_state:
    st.session_state.page = 0

if 'submit' not in st.session_state:
    st.session_state.submit = False

if 'detect' not in st.session_state:
    st.session_state.detect = False

if 'languages' not in st.session_state:
    st.session_state.languages = []


def setDetect():
    st.session_state.detect = True


def setSubmit():
    st.session_state.submit = True


def resetPage():
    st.session_state.page = 0


def uploadTSV():

    with st.form("Detect"):
        st.write(st.session_state.general_text_dict['text'])
        st.write(st.session_state.general_text_dict['text2'])
        st.file_uploader(
            st.session_state.general_text_dict['file'], type=["tsv", "csv"], key='file')
        st.form_submit_button(
            st.session_state.general_text_dict['detect'], on_click=setDetect)


def askTranslateLanguages(file):
    with st.form("Submit"):
        name = file.name
        st.write(name)
        st.write(
            st.session_state.general_text_dict['detected'] + st.session_state.detected)
        col1, col2 = st.columns(2)
        with col1:
            st.selectbox(st.session_state.general_text_dict['translate1'], st.session_state.languages,
                         key='srcLang')
        with col2:
            st.selectbox(st.session_state.general_text_dict['translate2'], st.session_state.languages,
                         key='destLang')
        st.form_submit_button(
            st.session_state.general_text_dict['submit'], on_click=setSubmit)
        # Page Code End


if st.session_state.page == 0:
    if st.session_state.detect:
        if st.session_state.file != None:
            with st.spinner(st.session_state.general_text_dict['loadingLanguages']):
                st.session_state.separator = getSeparator(
                    st.session_state.file)
                st.session_state.languages = inspectLanguages(
                    st.session_state.file)
            if len(st.session_state.languages) == 1:
                st.session_state.page = 3
                st.session_state.detect = False
            else:
                st.session_state.page = 1
                st.session_state.detect = False
                st.session_state.tmpFile = st.session_state.file
        else:
            uploadTSV()
    else:
        uploadTSV()


if st.session_state.page == 1:
    if st.session_state.submit and st.session_state.srcLang != st.session_state.destLang:
        st.session_state.page = 2
        st.session_state.submit = False
    else:
        askTranslateLanguages(st.session_state.tmpFile)

if st.session_state.page == 2:
    tsv = translateTSV(st.session_state.tmpFile)
    st.write(st.session_state.general_text_dict['new_file'])
    name = st.session_state.tmpFile.name
    st.download_button(name,
                       tsv, name, on_click=resetPage)

if st.session_state.page == 3:
    st.write(
        st.session_state.general_text_dict['sameLanguages'] + list(st.session_state.languages.keys())[0])
    st.session_state.languages = {}
    st.button(
        st.session_state.general_text_dict['anotherFile'], on_click=resetPage)
