"""
Streamlit Application
Nicolas Atrax
"""

import streamlit as st
import zipfile
import tempfile
import shutil
import os
import re
from datetime import date
from lib.langdetect.langdetect import detect
from lib.langdetect.langdetect.lang_detect_exception import LangDetectException
import src.basic as tmp

tmp.base("TXTtoTSV")

# Tool Code Start


def detectLanguages(abstract, languages):
    if re.search('[a-zA-Z]', abstract) == None:
        return languages
    try:
        tmp = detect(abstract)
        if tmp in languages:
            languages[tmp] += 1
        else:
            languages[tmp] = 1
    except LangDetectException:
        pass
    return languages


def estimateLanguagesPercentage(languages):
    total = 0
    max = 0
    principal = ""
    res = {}
    for l in languages:
        total += int(languages[l])
    for l in languages:
        tmp = int(languages[l]) / total * 100
        if tmp > max:
            max = tmp
            principal = l
        res[l] = tmp
    return res, principal


def detectMultipleLanguages(languages, fileName):
    languages, principal = estimateLanguagesPercentage(languages)
    detected = ""
    valuable = []
    for l in languages:
        if languages[l] >= 15:
            if detected != "":
                detected += "| "
            detected += l + " : " + str(languages[l]) + "%"
            valuable.append(l)
    if len(valuable) > 1:
        st.session_state.warning += st.session_state.general_text_dict['warning'] + "\"" + \
            fileName + "\" !\n"
        st.session_state.warning += st.session_state.general_text_dict['warning2'] + \
            detected + " \n"
        st.session_state.warning += st.session_state.general_text_dict['advice'] + "\n\n"
        return principal
    return principal


def detectMultipleTxtLanguages():
    languages = []
    for l in st.session_state.txtLanguages.values():
        if l not in languages and len(languages) == 1:
            st.info(st.session_state.general_text_dict['globalWarning'])
            st.info(str(st.session_state.txtLanguages))
            st.info(st.session_state.general_text_dict['advice'])
            return
        if len(languages) == 0:
            languages.append(l)


def segmentAbstract(abstract, tsv):
    year = str(date.today().year)
    month = "1"
    day = "1"
    source = st.session_state.title
    if source == "":
        source = st.session_state.file.name.replace('.txt', '')
    author = st.session_state.author
    nbLines = len(abstract)
    n = 0
    count = 1
    languages = {}
    while n < nbLines - 2:
        doc = "".join(abstract[n: n + 9]).replace("�", "")
        title = source + " : Part " + str(count)
        tsv += correctedSequence(author, False) + "\t" + correctedSequence(
            source, False) + "\t" + year + "\t" + month + "\t" + day + "\t"
        tsv += correctedSequence(title, False) + "\t"
        tsv += correctedSequence(doc, True)
        if tsv[-1] != "\n":
            tsv += "\n"
        n += 7
        count += 1
        if n > nbLines - 9 and n != nbLines - 2:
            n = nbLines - 9
        languages = detectLanguages(doc, languages)

    detectMultipleLanguages(languages, source)
    return tsv


def segmentAbstract2(abstract, tsv, author, title):
    year = str(date.today().year)
    month = "1"
    day = "1"
    source = title
    nbLines = len(abstract)
    n = 0
    count = 1
    languages = {}
    while n < nbLines - 2:
        doc = "".join(abstract[n: n + 9]).replace("�", "")
        title = source + " : Part " + str(count)
        tsv += correctedSequence(author, False) + "\t" + correctedSequence(
            source, False) + "\t" + year + "\t" + month + "\t" + day + "\t"
        tsv += correctedSequence(title, False) + "\t"
        tsv += correctedSequence(doc, True)
        if tsv[-1] != "\n":
            tsv += "\n"
        n += 7
        count += 1
        if n > nbLines - 9 and n != nbLines - 2:
            n = nbLines - 9
        languages = detectLanguages(doc, languages)

    st.session_state.txtLanguages[fileName] = detectMultipleLanguages(
        languages, source)
    return tsv


def correctedSequence(text, last):
    tmp = text.replace("\"", "\"\"")
    find = "\t" in text or "\"" in text or "\n" in text
    if find:
        if text[len(text) - 1] == "\n":
            tmp = tmp[:-1]
        tmp = "\"" + tmp + "\""
        if last:
            tmp += "\n"
    return tmp


def getTxt():
    txt = []
    st.session_state.tmpDir = tempfile.TemporaryDirectory()
    name = st.session_state.file.name
    with open(st.session_state.tmpDir.name + "/" + name, "wb") as file:
        file.write(st.session_state.file.getvalue())
    with open(st.session_state.tmpDir.name + "/" + name, "r") as file:
        for line in file:
            txt.append(line)
    return txt


def getTxt2(fileAddress):
    txt = []
    with open(fileAddress, "r") as file:
        for line in file:
            txt.append(line)
    return txt


def getInfo():
    title = st.session_state.title
    if title == "":
        title = st.session_state.fileName.replace(".txt", "")
    return st.session_state.author, title


def txtToTSV():

    fileName = st.session_state.file.name
    txt = getTxt()
    tsv = "authors\tsource\tpublication_year\tpublication_month\tpublication_day\ttitle\tabstract\n"
    tsv = segmentAbstract(txt, tsv)

    return tsv


def txtToTSV2(fileName, fileAddress, txtDir):
    st.session_state.page = 1
    author, title = getInfo()
    abstract = getTxt2(fileAddress)
    tsv = "authors\tsource\tpublication_year\tpublication_month\tpublication_day\ttitle\tabstract\n"
    with st.spinner(st.session_state.general_text_dict['loading']):
        tsv = segmentAbstract2(abstract, tsv, author, title)
    if '/' in fileName:
        fileName = fileName.split('/')[1]
    with open(txtDir + "/" + fileName.replace(".txt", "(txt).tsv"), "w", encoding="utf-8-sig") as file:
        file.write(tsv)

    tsv = "\n".join(tsv.split("\n")[1:])
    return tsv


def extractAllTXT(zipDir, zipFile):
    with zipfile.ZipFile(zipFile) as zipRef:
        zipInfos = zipRef.infolist()
        for info in zipInfos:
            while '/' in info.filename and len(info.filename.split('/')) > 1:
                info.filename = "/".join(info.filename.split('/')[1:])
            if ".txt" in info.filename:
                zipRef.extract(info, zipDir)


# Tool Code End


form = st.form('api')

# Page Code Start

if 'page' not in st.session_state:
    st.session_state.page = 0

if 'warning' not in st.session_state:
    st.session_state.warning = ""

if 'submit' not in st.session_state:
    st.session_state.submit = False

if 'zipSubmit' not in st.session_state:
    st.session_state.zipSubmit = False

if 'txtLanguages' not in st.session_state:
    st.session_state.txtLanguages = {}


def setSubmit():
    st.session_state.submit = True


def setZIPSubmit():
    st.session_state.zipSubmit = True


def resetPage():
    st.session_state.page = 0


def upPage():
    st.session_state.page = 3


def uploadZip():
    with st.form("Submit2"):
        st.write(st.session_state.general_text_dict['text2'])
        st.file_uploader(
            st.session_state.general_text_dict['file'], type=["zip"], key='zipFile')
        st.form_submit_button(
            st.session_state.general_text_dict['submit'], on_click=setZIPSubmit)


def askTXT():

    with st.form("Submit"):
        st.write(st.session_state.general_text_dict['text'])
        st.write(st.session_state.general_text_dict['text3'])
        col1, col2 = st.columns(2)
        st.session_state.author = ""
        with col1:
            st.text_input(
                st.session_state.general_text_dict['author'], key='author')
        with col2:
            st.text_input(
                st.session_state.general_text_dict['titleTXT'], key='title')
        st.file_uploader(
            st.session_state.general_text_dict['file'], type=["txt"], key='file')
        st.form_submit_button(
            st.session_state.general_text_dict['submit'], on_click=setSubmit)


def askTXT2(fileName):

    with st.form("Submit"):
        st.write(fileName)
        st.write(st.session_state.general_text_dict['text3'])
        col1, col2 = st.columns(2)
        st.session_state.author = ""
        with col1:
            st.text_input(
                st.session_state.general_text_dict['author'], key='author')
        with col2:
            st.text_input(
                st.session_state.general_text_dict['titleTXT'], key='title')
        st.form_submit_button(
            st.session_state.general_text_dict['submit'], on_click=upPage)

# Page Code End


if st.session_state.page == 0:
    if st.session_state.submit:
        st.session_state.submit = False
        if st.session_state.file != None:
            st.session_state.page = 1
        else:
            askTXT()
            uploadZip()
    elif st.session_state.zipSubmit:
        st.session_state.zipSubmit = False
        if st.session_state.zipFile != None:
            st.session_state.zipDir = tempfile.TemporaryDirectory()
            st.session_state.txtDir = tempfile.TemporaryDirectory()
            st.session_state.tsv = "authors\tsource\tpublication_year\tpublication_month\tpublication_day\ttitle\tabstract"
            extractAllTXT(st.session_state.zipDir.name,
                          st.session_state.zipFile)
            st.session_state.len = len(
                os.listdir(st.session_state.zipDir.name))
            st.session_state.nbDoc = 0
            st.session_state.page = 2
        else:
            askTXT()
            uploadZip()
    else:
        askTXT()
        uploadZip()

if st.session_state.page == 1:
    name = st.session_state.file.name
    txt = txtToTSV()
    name = st.session_state.file.name.split('.')[0] + '.tsv'
    st.write(st.session_state.general_text_dict['new_file'])
    st.session_state.submit = False
    if st.session_state.warning != "":
        st.info(st.session_state.warning)
    st.download_button(name, txt, name, on_click=resetPage)

if st.session_state.page == 3:
    fileName = st.session_state.fileName
    tmp = txtToTSV2(
        fileName, st.session_state.zipDir.name + '/' + fileName, st.session_state.txtDir.name)
    st.session_state.tsv += "\n" + tmp
    if st.session_state.nbDoc == st.session_state.len - 1:
        st.session_state.page = 4
    else:
        st.session_state.nbDoc += 1
        st.session_state.page = 2

if st.session_state.page == 2:
    fileName = os.listdir(st.session_state.zipDir.name)[st.session_state.nbDoc]
    st.session_state.fileName = fileName
    if '/' in fileName:
        fileName = fileName.split('/')[1]
    askTXT2(fileName)

if st.session_state.page == 4:
    with open(st.session_state.txtDir.name + "/TXTCompilation.tsv", "w", encoding='utf-8-sig') as file:
        file.write(st.session_state.tsv)
    shutil.make_archive(st.session_state.zipDir.name +
                        "/TXTCompilation", 'zip', st.session_state.txtDir.name)
    with open(st.session_state.zipDir.name + "/TXTCompilation.zip", 'rb') as zip:
        if st.session_state.warning != "":
            st.info(st.session_state.warning)
        detectMultipleTxtLanguages()
        st.write(st.session_state.general_text_dict['new_file'])
        st.download_button("TXTCompilation.zip",
                           zip, "TXTCompilation.zip", on_click=resetPage)
