"""
Streamlit Application
Nicolas Atrax
"""

import streamlit as st
import tempfile
import shutil
from datetime import date
from youtubesearchpython import VideosSearch
from lib.youtubetranscript.youtube_transcript_api import YouTubeTranscriptApi
from lib.youtubetranscript.youtube_transcript_api._transcripts import NoTranscriptFound
from lib.youtubetranscript.youtube_transcript_api._transcripts import TranscriptsDisabled
import src.basic as tmp
import time
import random

tmp.base("YTBtoTSV")

# Tool Code Start


def ytbSearch(search, n):
    if st.session_state.videoLang == 'fr':
        region = 'FR'
    else:
        region = 'US'
    videosSearch = VideosSearch(search, region=region)
    result = videosSearch.result()["result"]
    videos = []
    while len(videos) < n:
        for video in result:
            id = video["id"]
            title = video["title"]
            author = video["channel"]["name"]
            videos.append([id, author, title])
            if len(videos) == n:
                break
        if len(videos) == n:
            break
        tmpResult = result
        videosSearch.next()
        time.sleep(1.0)
        result = videosSearch.result()["result"]
        if result == tmpResult:
            break
    return videos


def getLang(list):
    tmp = ""
    for lang in list:
        tmp = str(lang).split(" ")[0]
        if tmp == st.session_state.videoLang:
            break
    return tmp


def translateTranscript(lst, lang):
    origin = lst.find_transcript([lang])
    manual = not origin.is_generated
    return origin.translate(st.session_state.videoLang).fetch(), manual


def ytbTranscript(id, title):
    try:
        transcriptList = YouTubeTranscriptApi.list_transcripts(id)
        lang = getLang(transcriptList)
        if lang != st.session_state.videoLang:
            return translateTranscript(transcriptList, lang)
        try:
            transcript = transcriptList.find_manually_created_transcript(
                [st.session_state.videoLang]).fetch()
            return transcript, True
        except NoTranscriptFound:
            try:
                transcript = transcriptList.find_generated_transcript(
                    [st.session_state.videoLang]).fetch()
                return transcript, False
            except NoTranscriptFound:
                return None, False
    except TranscriptsDisabled:
        return None, False


def tsvAdd(tsv, abstract, author, title, date, count):
    part = title + " : Part " + str(count)
    tsv += correctedSequence(author, False) + "\t" + correctedSequence(
        title, False) + "\t" + date + "\t" + "1" + "\t" + "1" + "\t"
    tsv += correctedSequence(part, False) + "\t"
    tsv += correctedSequence(abstract, True)
    return tsv


def transcriptAutomaticToDoc(transcript, author, title, date):
    tsv = "authors\tsource\tpublication_year\tpublication_month\tpublication_day\ttitle\tabstract\n"
    time = 0
    count = 1
    tmp = ""
    for part in transcript:
        tmp += part["text"] + "\n"
        time += float(part["duration"])
        if time >= 15:
            tsv = tsvAdd(tsv, tmp, author, title, date, count)
            tmp = ""
            time = 0
            count += 1

    with open(st.session_state.zipDir.name + "/" + title + ".tsv", "w", encoding="utf-8-sig") as file:
        file.write(tsv)
    tsv = "\n".join(tsv.split("\n")[1:])
    return tsv


def detectPoint(text):
    if "." in text:
        tmp2 = text.split(".")
        return True, ".", tmp2
    elif "!" in text:
        tmp2 = text.split("!")
        return True, "!", tmp2
    elif "?" in text:
        tmp2 = text.split("?")
        return True, "?", tmp2
    return False, "", ""


def transcriptManualToDoc(transcript, author, title, date):
    tsv = "authors\tsource\tpublication_year\tpublication_month\tpublication_day\ttitle\tabstract\n"
    time = 0
    count = 1
    tmp = ""
    end = False
    for part in transcript:
        text = part["text"]
        split, end, tmp2 = detectPoint(text)
        if split:
            if time >= 10:
                tmp += tmp2[0] + end
                tsv = tsvAdd(tsv, tmp, author, title, date, count)
                tmp = text[len(tmp2[0]) + 1:]
                time = 0
                count += 1
            else:
                tmp += text + "\n"
                time += float(part["duration"])
        else:
            tmp += text + " "
            time += float(part["duration"])
            if time >= 20:
                tsv = tsvAdd(tsv, tmp, author, title, date, count)
                tmp = ""
                time = 0
                count += 1

    with open(st.session_state.zipDir.name + "/" + title + ".tsv", "w", encoding="utf-8-sig") as file:
        file.write(tsv)
    tsv = "\n".join(tsv.split("\n")[1:])
    return tsv


def correctedSequence(text, last):
    tmp = text.replace("\"", "\"\"")
    find = "\t" in text or "\"" in text or "\n" in text
    if find:
        if text[len(text) - 1] == "\n":
            tmp = tmp[:-1]
        tmp = "\"" + tmp + "\""
    if last:
        tmp += "\n"
    return tmp


def correctTranscript(transcript):
    res = []
    time = 0
    for part in transcript:
        start = float(part["start"])
        duration = float(part["duration"])
        if start >= time and duration > 0.5:
            res.append(part)
            if (start != time):
                time = start
            time += duration
    return res


def transcriptToTsv(search, nbVideos):
    tsv = "authors\tsource\tpublication_year\tpublication_month\tpublication_day\ttitle\tabstract\n"
    dict = st.session_state.general_text_dict
    with st.spinner(dict['loadingID']):
        if st.session_state.manualOnly:
            videos = ytbSearch(search, nbVideos * 15)
        else:
            videos = ytbSearch(search, nbVideos * 5)
    count = 0
    countTotal = 0
    bar = st.progress(count / nbVideos, dict['loading'] +
                      str(count) + dict['quantity'] + str(nbVideos))
    for video in videos:
        countTotal += 1
        waitingTime = random.uniform(2.0, 7.0)
        # print("Waiting time : " + str(waitingTime))
        time.sleep(waitingTime)
        # print(countTotal)
        bar.progress(count / nbVideos, dict['loading'] +
                     str(count) + dict['quantity'] + str(nbVideos))
        if count == nbVideos:
            break
        id, author, title = video[0], video[1], video[2]
        if "/" in title:
            continue
        transcript, manual = ytbTranscript(id, title)
        if transcript == None:
            continue
        transcript = correctTranscript(transcript)
        if manual:
            tsv += transcriptManualToDoc(transcript,
                                         author, title, str(date.today().year))
            count += 1
        elif not st.session_state.manualOnly:
            tsv += transcriptAutomaticToDoc(transcript,
                                            author, title, str(date.today().year))
            count += 1
    with open(st.session_state.zipDir.name + "/" + "VideosCompilation.tsv", "w", encoding="utf-8-sig") as file:
        file.write(tsv)


# Tool Code End
form = st.form('api')

# Page Code Start

if 'page' not in st.session_state:
    st.session_state.page = 0

if 'submit' not in st.session_state:
    st.session_state.submit = False


def setSubmit():
    st.session_state.submit = True


def resetPage():
    st.session_state.page = 0


def askVideos():
    with st.form("Submit"):
        st.write(st.session_state.general_text_dict['text'])
        st.write(st.session_state.general_text_dict['text2'])
        st.selectbox(st.session_state.general_text_dict['videoLang'], ['fr', 'en'],
                     key='videoLang')
        st.text_input(
            st.session_state.general_text_dict['keywords'], key='keywords')
        st.slider(
            st.session_state.general_text_dict['number'], 1, 20, key='nb_taken')
        st.checkbox(
            st.session_state.general_text_dict['fill'], key='manualOnly')
        st.form_submit_button(
            st.session_state.general_text_dict['submit'], on_click=setSubmit)

# Page Code End


if st.session_state.page == 0:
    if st.session_state.submit:
        st.session_state.submit = False
        if st.session_state.keywords != "":
            st.session_state.page = 1
        else:
            askVideos()
    else:
        askVideos()


if st.session_state.page == 1:
    st.session_state.zipDir = tempfile.TemporaryDirectory()
    transcriptToTsv(st.session_state.keywords, st.session_state.nb_taken)
    st.session_state.tmpDir = tempfile.TemporaryDirectory()
    compilName = st.session_state.tmpDir.name + "/" + st.session_state.keywords
    shutil.make_archive(compilName, 'zip', st.session_state.zipDir.name)
    with open(compilName + ".zip", 'rb') as zip:
        st.write(st.session_state.general_text_dict['new_file'])
        st.download_button(st.session_state.keywords + ".zip",
                           zip, st.session_state.keywords + ".zip", on_click=resetPage)
