"""
Streamlit Application
Loïc Chapron
"""

import streamlit as st
import requests as req
import json
from datetime import date
import src.basic as tmp


tmp.base("ZoteroToGarganText")


sizepage = 10
limit = 50  # This value cannot exceed 100 !


def getAllItems(id):
    txt, nb = loadApiItems(12093554, 0)
    if txt != 0:
        for i in range(1, int(nb)//10 + 1):
            tmp, tmp2 = loadApiItems(id, i)
            txt += tmp

        return txt
    else:
        return 0


def loadApiItems(id, page):
    url = 'https://api.zotero.org/users/' + str(id) + '/items/top?limit=' + str(
        limit) + '&start=' + str(page * limit) + '&direction=asc&sort=title'
    resp = req.get(url)
    if resp.ok:
        jsontxt = json.loads(resp.content)
        return jsontxt, resp.headers['Total-Results']
    else:
        return 0, 0


def loadApiCollections(id):

    url = 'https://api.zotero.org/users/' + str(id) + '/collections'
    resp = req.get(url)
    if resp.ok:
        jsontxt = json.loads(resp.content)
        return jsontxt
    else:
        return 0


def loadApiItemsByCollections(id, key):

    url = 'https://api.zotero.org/users/' + \
        str(id) + '/collections/' + str(key) + '/items/top'
    resp = req.get(url)
    if resp.ok:
        jsontxt = json.loads(resp.content)
        return jsontxt
    else:
        return 0


def getAllCollections(docs):
    output = {}
    for doc in docs:
        output[doc['data']['name']] = doc['data']['key']
    return output


def getParamFromDoc(doc):
    # Title

    title = doc['data']['title']

    # Authors

    if 'creators' in doc['data'].keys():
        authors = []
        for author in doc['data']['creators']:
            authors.append(author['lastName'])
        authors = ';'.join(authors)
    else:
        authors = ''

    # Source

    source = doc['data']['url']

    # Abstract
    if 'abstractNote' in doc['data'].keys():
        abstract = doc['data']['abstractNote']
    else:
        abstract = ''

    # Date

    if 'date' in doc['data'].keys() and doc['data']['date'] != '':
        pdate = doc['data']['date'].split('-')
        pdate[2] = pdate[2].split('T')[0]
        pdate = '\t'.join(pdate)
    else:
        pdate = str(date.today().year) + '\t1\t1'

    abstract = abstract.encode(encoding='UTF-8', errors='ignore').decode(
        "utf-8").replace('\t', '').replace('"', '').replace('\n', '')
    title = title.encode(encoding='UTF-8', errors='ignore').decode(
        "utf-8").replace('\t', '').replace('"', '').replace('\n', '')
    source = source.encode(encoding='UTF-8', errors='ignore').decode(
        "utf-8").replace('\t', '').replace('"', '').replace('\n', '').replace('\n', '')

    # Output
    return str(title) + "\t" + source + "\t" + str(pdate) + "\t" + abstract + "\t" + authors + "\t" + str(1) + "\n"


def createTSV(docs):
    # Output text
    output = "title\tsource\tpublication_year\tpublication_month\tpublication_day\tabstract\tauthors\tweight\n"

    for doc in docs:

        output += getParamFromDoc(doc)

    return output


def createTSVfromCollections():
    # Output text
    output = "title\tsource\tpublication_year\tpublication_month\tpublication_day\tabstract\tauthors\tweight\n"

    for elem in st.session_state.collectionsKey:
        docs = loadApiItemsByCollections(st.session_state.id, elem)
        for doc in docs:
            output += getParamFromDoc(doc)
    return output


# Stage setting and function

if 'stage' not in st.session_state:
    st.session_state.stage = 0
    st.session_state.id = ''
    st.session_state.format = 'items'


def set_stage(stage):
    st.session_state.stage = stage
    st.session_state.id = st.session_state.idForm
    st.session_state.format = st.session_state.formatForm
    if st.session_state.format == 'items':
        st.session_state.page = 0
        st.session_state.docs = []
        st.session_state.zotero_search = ''
        st.session_state.docsByKey = {}
        st.session_state.select = False


def set_stage_collections(stage):
    st.session_state.stage = stage
    st.session_state.collectionsKey = []
    for elem in st.session_state.collectionsForm:
        st.session_state.collectionsKey.append(
            st.session_state.collections[elem])


def set_stage_items(stage):
    st.session_state.stage = stage
    st.session_state.result = []
    saveKey()
    for elem in st.session_state.docsByKey.values():
        if elem[1]:
            st.session_state.result.append(elem[0])


def set_stage_minus():
    st.session_state.stage -= 1


def saveKey():
    for elem in st.session_state.keys():
        if 'itemskey-' in elem:
            st.session_state.docsByKey[elem.split(
                '-')[1]][1] = st.session_state[elem]


def fill_docs():
    st.session_state.docs = []
    for elem in list(st.session_state.docsByKey.values()):
        if st.session_state.zotero_search in elem[0]['data']['title']:
            st.session_state.docs.append(elem[0])


def selectAll():
    st.session_state.select = not st.session_state.select
    for elem in st.session_state.docs:
        st.session_state.docsByKey[elem['data']['key']] = [
            elem, st.session_state.select]


def clear_docs():
    st.session_state.page = 0

    saveKey()
    fill_docs()

    st.session_state.select = False
    st.session_state.nbdoc = len(st.session_state.docs)


# items page function

def switch_page(value):
    if value == 'up':
        st.session_state.page += 1
    elif value == 'down':
        st.session_state.page -= 1

    saveKey()
    fill_docs()


# Begin page
if st.session_state.stage == 0:

    # Form
    form = st.form('api')

    lst = ['items', 'collections']
    st.session_state.id = form.text_input(
        'ID', st.session_state.id, key='idForm', help=st.session_state.general_text_dict['help'])
    st.session_state.format = form.selectbox(
        st.session_state.general_text_dict['data'], lst, lst.index(st.session_state.format), key='formatForm')

    form.form_submit_button(
        st.session_state.general_text_dict['submit'], on_click=set_stage, args=(1,))


# page for select items
if st.session_state.stage == 1 and st.session_state.format == 'items':
    if (st.session_state.docsByKey == {}):
        st.session_state.docs = getAllItems(st.session_state.id)
        if st.session_state.docs != 0:
            for doc in st.session_state.docs:
                st.session_state.docsByKey[doc['data']['key']] = [doc, False]
            clear_docs()

    if st.session_state.docs == 0:
        st.write(st.session_state.general_text_dict['denied'])
    else:
        st.write(st.session_state.general_text_dict['add_doc'])
        st.checkbox(
            st.session_state.general_text_dict['select_all'], st.session_state.select, on_change=selectAll)
        st.text_input(
            st.session_state.general_text_dict['search'], key='zotero_search', on_change=clear_docs)
        min = st.session_state.page * sizepage
        max = st.session_state.page * sizepage + sizepage
        for doc in st.session_state.docs[min:max]:
            st.checkbox(doc['data']['title'], st.session_state.docsByKey[doc['data']
                        ['key']][1], key='itemskey-'+doc['data']['key'])
        col1, col2 = st.columns(2)
        with col1:
            st.button(
                st.session_state.general_text_dict['submit'], on_click=set_stage_items, args=(2,))
        with col2:
            nb = int(st.session_state.nbdoc)//sizepage
            # Fix the problem where the page end on the last file but there is still a page left
            if int(st.session_state.nbdoc) % sizepage == 0:
                nb -= 1
            if nb != 0:
                col3, col4 = st.columns(2)
                with col3:
                    if st.session_state.page != 0:
                        st.button(
                            st.session_state.general_text_dict['p_page'], on_click=switch_page, args=('down',))
                with col4:
                    if st.session_state.page != nb:
                        st.button(
                            st.session_state.general_text_dict['n_page'], on_click=switch_page, args=('up',))


# page for select collections
if st.session_state.stage == 1 and st.session_state.format == 'collections':
    docs = loadApiCollections(st.session_state.id)

    if docs == 0:
        st.write(st.session_state.general_text_dict['denied'])
    else:
        collections = getAllCollections(docs)
        st.session_state.collections = collections
        form = st.form('collection')
        form.write(st.session_state.general_text_dict['add_collect'])
        form.multiselect(st.session_state.general_text_dict['chose_collect'], collections.keys(
        ), key='collectionsForm')
        form.form_submit_button(
            st.session_state.general_text_dict['submit'], on_click=set_stage_collections, args=(2,))

# page for TSV items
if st.session_state.stage == 2 and st.session_state.format == 'items':
    st.write(st.session_state.general_text_dict['fileTSV1'] + str(
        len(st.session_state.result)) + st.session_state.general_text_dict['fileTSV2'])
    output = createTSV(st.session_state.result)
    st.download_button('Download TSV', output, 'output.csv')

# page for TSV collections
if st.session_state.stage == 2 and st.session_state.format == 'collections':
    output = createTSVfromCollections()
    st.write(st.session_state.general_text_dict['fileTSV1'] + str(
        len(output.split('\n'))-2) + st.session_state.general_text_dict['fileTSV2'])
    st.download_button('Download TSV', output, 'output.csv')


if st.session_state.stage > 0:
    st.button(
        st.session_state.general_text_dict['back'], on_click=set_stage_minus)
